pub enum Nettype {
In,
Other(String),
}Expand description
The Nettype as it appears in the connection or origin lines. It’s not a Copy type since it
supports abstract types, not even defined in any RFC.
Variants